==> jwinner-kit-0.0.3-sources.jar: itez/kit/EWeb.java <==
package itez.kit;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.net.URLEncoder;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Map;
import java.util.regex.Pattern;

import javax.servlet.ServletInputStream;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * WEB工具类
 * @author netwild
 */
public abstract class EWeb {

	private static Logger log = LoggerFactory.getLogger(EWeb.class);

	/**
	 * 获取客户端IP地址
	 * @param request
	 * @return
	 */
	public static String getIpAddr(HttpServletRequest request) {
		String ip = request.getHeader("x-forwarded-for");
		if (EStr.isEmpty(ip) || "unknown".equalsIgnoreCase(ip)) ip = request.getHeader("Proxy-Client-IP");
		if (EStr.isEmpty(ip) || "unknown".equalsIgnoreCase(ip)) ip = request.getHeader("WL-Proxy-Client-IP");
		if (EStr.isEmpty(ip) || "unknown".equalsIgnoreCase(ip)) ip = request.getHeader("HTTP_CLIENT_IP");
		if (EStr.isEmpty(ip) || "unknown".equalsIgnoreCase(ip)) ip = request.getHeader("HTTP_X_FORWARDED_FOR");
		if (EStr.isEmpty(ip) || "unknown".equalsIgnoreCase(ip)) ip = request.getHeader("HTTP_X_FORWARDED");
		if (EStr.isEmpty(ip) || "unknown".equalsIgnoreCase(ip)) ip = request.getHeader("HTTP_FORWARDED_FOR");
		if (EStr.isEmpty(ip) || "unknown".equalsIgnoreCase(ip)) ip = request.getHeader("HTTP_FORWARDED");
		if (EStr.isEmpty(ip) || "unknown".equalsIgnoreCase(ip)) ip = request.getRemoteAddr();
		return ip;
	}

	/**
	 * 获取应用根路径（格式：http://www.domain.com:8888/app）
	 * 
	 * @param request
	 * @return
	 */
	public static String getContextPath(HttpServletRequest request) {
		StringBuilder sb = new StringBuilder();
		sb.append(request.getScheme()).append("://").append(request.getServerName());
		int port = request.getServerPort();
		if(port != 80 && port != 443){
			sb.append(":").append(port);
		}
		sb.append(request.getContextPath());
		String path = sb.toString();
		return path;
	}

	/**
	 * 获取完整请求路径(含内容路径及请求参数)
	 * 
	 * @param request
	 * @return
	 */
	public static String getFullUrl(HttpServletRequest request) {
		String resUrl = request.getRequestURL().toString();
		String params = request.getQueryString();
		if(EStr.notEmpty(params)) resUrl += "?" + params;
		return resUrl;
	}
	
	/**
	 * 获取请求来源路径
	 * 
	 * @param request
	 * @return
	 */
	public static String getReferer(HttpServletRequest request){
		return request.getHeader("referer");
	}
	
	/**
	 * 地址栏参数编码
	 * 
	 * @param url
	 * @return
	 */
	public static String UrlEncoder(String url){
		String urlEncode = url;
		try {
			urlEncode = URLEncoder.encode(url, EStr.Encoding);
		} catch (Exception e) {
			if(EProp.DevMode) e.printStackTrace();
		}
		return urlEncode;
	}
	
	/**
	 * 地址栏参数解码
	 * 
	 * @param url
	 * @return
	 */
	public static String UrlDecoder(String url){
		String urlDecode = url;
		try {
			urlDecode = URLDecoder.decode(url, EStr.Encoding);
		} catch (Exception e) {
			if(EProp.DevMode) e.printStackTrace();
		}
		return urlDecode;
	}

	/**
	 * 获取请求参数
	 * 
	 * @param request
	 * @param name
	 * @return
	 */
	public static String getParam(HttpServletRequest request, String name) {
		String value = request.getParameter(name);
		if (null != value && !value.isEmpty()) {
			try {
				return URLDecoder.decode(value, EStr.Encoding).trim();
			} catch (UnsupportedEncodingException e) {
				log.error("decode异常：" + value);
				return value;
			}
		}
		return value;
	}

	/**
	 * 获取ParameterMap
	 * @param request
	 * @return
	 */
	public static Map<String, String> getParamMap(HttpServletRequest request){
		Map<String, String> map = new HashMap<String, String>();
		Enumeration<String> enume = request.getParameterNames();
		while (enume.hasMoreElements()) {
			String name = (String) enume.nextElement();
			map.put(name, getParam(request, name));
		}
		return map;
	}
	
	/**
	 * 判断是否为Ajax请求
	 * @param request
	 * @return
	 */
	public static boolean isAjax(HttpServletRequest request){
        String header = request.getHeader("X-Requested-With");
        return "XMLHttpRequest".equalsIgnoreCase(header);
	}

	/**
	 * 输出servlet文本内容
	 * 
	 * @param response
	 * @param content
	 * @param contentType
	 */
	public static void outPage(HttpServletResponse response, String content) {
		outPage(response, content, EStr.Encoding);
	}

	/**
	 * 输出servlet文本内容
	 * 
	 * @param response
	 * @param content
	 * @param contentType
	 */
	public static void outPage(HttpServletResponse response, String content, String contentType) {
		if(EStr.isEmpty(contentType)) contentType = EStr.Encoding;
		response.setContentType(String.format("text/html; charset=%s", contentType));
		response.setCharacterEncoding(EStr.Encoding);
		try {
			byte[] contentBytes = content.getBytes(contentType);
			outPage(response, contentBytes, contentType);
			
			/*
			//改用ServletOutputStream输出，性能更好
			PrintWriter out = response.getWriter();
			out.print(content);
			out.flush();
			out.close();
			*/
			
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * 输出servlet文本内容
	 * 
	 * @param response
	 * @param content
	 * @param contentType
	 */
	public static void outPage(HttpServletResponse response, byte[] content, String contentType) {
		if(EStr.isEmpty(contentType)) contentType = EStr.Encoding;
		response.setContentType(String.format("text/html; charset=%s", contentType));
		response.setCharacterEncoding(EStr.Encoding);
		try {
			ServletOutputStream out = response.getOutputStream();
			out.write(content);
			out.flush();
			out.close();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * 请求流转字符串
	 * 
	 * @param request
	 * @return
	 */
	public static String requestStream(HttpServletRequest request) {
		InputStream inputStream = null;
		InputStreamReader inputStreamReader = null;
		BufferedReader bufferedReader = null;
		try {
			request.setCharacterEncoding(EStr.Encoding);
			inputStream = (ServletInputStream) request.getInputStream();
			inputStreamReader = new InputStreamReader(inputStream, EStr.Encoding);
			bufferedReader = new BufferedReader(inputStreamReader);
			String line = null;
			StringBuilder sb = new StringBuilder();
			while ((line = bufferedReader.readLine()) != null) {
				sb.append(line);
			}
			return sb.toString();
		} catch (IOException e) {
			log.error("request.getInputStream() to String 异常", e);
			return null;
		} finally { // 释放资源
			if(null != bufferedReader){
				try {
					bufferedReader.close();
				} catch (IOException e) {
					log.error("bufferedReader.close()异常", e);
				}
				bufferedReader = null;
			}
			
			if(null != inputStreamReader){
				try {
					inputStreamReader.close();
				} catch (IOException e) {
					log.error("inputStreamReader.close()异常", e);
				}
				inputStreamReader = null;
			}
			
			if(null != inputStream){
				try {
					inputStream.close();
				} catch (IOException e) {
					log.error("inputStream.close()异常", e);
				}
				inputStream = null;
			}
		}
	}
	
	/**
	 * 
	 * @param response
	 * @param domain		设置cookie所在域
	 * @param path			设置cookie所在路径
	 * @param isHttpOnly	是否只读
	 * @param name			cookie的名称
	 * @param value			cookie的值
	 * @param maxAge		cookie存放的时间(以秒为单位,假如存放三天,即3*24*60*60; 如果值为0,cookie将随浏览器关闭而清除)
	 */
	public static void addCookie(HttpServletRequest request, HttpServletResponse response, 
			String domain, String path, boolean isHttpOnly, 
			String name, String value, int maxAge) {
		Cookie cookie = new Cookie(name, value);

		// 所在域：比如a1.4bu4.com 和 a2.4bu4.com 共享cookie
		if(null != domain && !domain.isEmpty()){
			cookie.setDomain(domain);
		}
		
		// 设置cookie所在路径
		cookie.setPath("/");
		if(null != path && !path.isEmpty()){
			cookie.setPath(path);				
		}
		
		// 是否只读
		try {
			cookie.setHttpOnly(isHttpOnly);
		} catch (Exception e) {
			log.error("servlet容器版本太低，servlet3.0以前不支持设置cookie只读" + e.getMessage());
		}
		
		// 设置cookie的过期时间
		if (maxAge > 0){
			cookie.setMaxAge(maxAge);
		}
		
		// 添加cookie
		response.addCookie(cookie);
		/*
		System.out.println("cookie.getDomain：" + cookie.getDomain());
		System.out.println("cookie.getPath：" + cookie.getPath());
		System.out.println("cookie.getMaxAge：" + cookie.getMaxAge());
		System.out.println("cookie.getName：" + cookie.getName());
		System.out.println("cookie.getValue：" + cookie.getValue());
		Cookie[] cookies = request.getCookies();
		System.out.println("cookies：" + cookies.length);
		*/
	}

	/**
	 * 获取cookie的值
	 * 
	 * @param request
	 * @param name cookie的名称
	 * @return
	 */
	public static String getCookieValueByName(HttpServletRequest request, String name) {
		Cookie cookie = getCookieByName(request, name);
		if(cookie != null) return cookie.getValue();
		return null;
	}
	
	/**
	 * 清除cookie
	 * @param request
	 * @param response
	 * @param name cookie的名称
	 */
	public static void clearCookieByName(HttpServletRequest request, HttpServletResponse response, String name){
		Cookie cookie = getCookieByName(request, name);
		if(cookie != null){
			cookie.setValue(null);
			cookie.setPath("/");
			cookie.setMaxAge(0);
			response.addCookie(cookie);
		}
	}

	/**
	 * 获得cookie
	 * 
	 * @param request
	 * @param name cookie的名称
	 * @return
	 */
	public static Cookie getCookieByName(HttpServletRequest request, String name) {
		Map<String, Cookie> cookieMap = EWeb.readCookieMap(request);
		// 判断cookie集合中是否有我们像要的cookie对象 如果有返回它的值
		if (cookieMap.containsKey(name)) {
			Cookie cookie = (Cookie) cookieMap.get(name);
			return cookie;
		} else {
			return null;
		}
	}

	/**
	 * 获得所有cookie
	 * 
	 * @param request
	 * @return
	 */
	public static Map<String, Cookie> readCookieMap(HttpServletRequest request) {
		Map<String, Cookie> cookieMap = new HashMap<String, Cookie>();
		// 从request范围中得到cookie数组 然后遍历放入map集合中
		Cookie[] cookies = request.getCookies();
		//System.out.println("cookies：" + cookies.length);
		if (null != cookies) {
			for (int i = 0; i < cookies.length; i++) {
				cookieMap.put(cookies[i].getName(), cookies[i]);
			}
		}
		return cookieMap;
	}

	/**
	 * 去除HTML代码
	 * 
	 * @param inputString
	 * @return
	 */
	public static String HtmltoText(String inputString) {
		String htmlStr = inputString; // 含HTML标签的字符串
		String textStr = "";
		java.util.regex.Pattern p_script;
		java.util.regex.Matcher m_script;
		java.util.regex.Pattern p_style;
		java.util.regex.Matcher m_style;
		java.util.regex.Pattern p_html;
		java.util.regex.Matcher m_html;
		java.util.regex.Pattern p_ba;
		java.util.regex.Matcher m_ba;

		try {
			String regEx_script = "<[\\s]*?script[^>]*?>[\\s\\S]*?<[\\s]*?\\/[\\s]*?script[\\s]*?>"; // 定义script的正则表达式{或<script[^>]*?>[\\s\\S]*?<\\/script>
																										// }
			String regEx_style = "<[\\s]*?style[^>]*?>[\\s\\S]*?<[\\s]*?\\/[\\s]*?style[\\s]*?>"; // 定义style的正则表达式{或<style[^>]*?>[\\s\\S]*?<\\/style>
																									// }
			String regEx_html = "<[^>]+>"; // 定义HTML标签的正则表达式
			String patternStr = "\\s+";

			p_script = Pattern.compile(regEx_script, Pattern.CASE_INSENSITIVE);
			m_script = p_script.matcher(htmlStr);
			htmlStr = m_script.replaceAll(""); // 过滤script标签

			p_style = Pattern.compile(regEx_style, Pattern.CASE_INSENSITIVE);
			m_style = p_style.matcher(htmlStr);
			htmlStr = m_style.replaceAll(""); // 过滤style标签

			p_html = Pattern.compile(regEx_html, Pattern.CASE_INSENSITIVE);
			m_html = p_html.matcher(htmlStr);
			htmlStr = m_html.replaceAll(""); // 过滤html标签

			p_ba = Pattern.compile(patternStr, Pattern.CASE_INSENSITIVE);
			m_ba = p_ba.matcher(htmlStr);
			htmlStr = m_ba.replaceAll(""); // 过滤空格

			textStr = htmlStr;

		} catch (Exception e) {
			System.err.println("Html2Text: " + e.getMessage());
		}
		return textStr;// 返回文本字符串
	}

	/**
	 * 把页面的信息替换成我们想要的信息存放数据库里面
	 * 
	 * @param sourcestr
	 *            页面得到的信息
	 * @return
	 */
	public static String getHTMLToString(String sourcestr) {
		if (sourcestr == null) {
			return "";
		}
		sourcestr = sourcestr.replaceAll("\\x26", "&amp;");// &
		sourcestr = sourcestr.replaceAll("\\x3c", "&lt;");// <
		sourcestr = sourcestr.replaceAll("\\x3e", "&gt;");// >
		sourcestr = sourcestr.replaceAll("\\x09", "&nbsp;&nbsp;&nbsp;&nbsp;");// tab键
		sourcestr = sourcestr.replaceAll("\\x20", "&nbsp;");// 空格
		sourcestr = sourcestr.replaceAll("\\x22", "&quot;");// "

		sourcestr = sourcestr.replaceAll("\r\n", "<br>");// 回车换行
		sourcestr = sourcestr.replaceAll("\r", "<br>");// 回车
		sourcestr = sourcestr.replaceAll("\n", "<br>");// 换行
		return sourcestr;
	}

	/**
	 * 把数据库里面的信息回显到页面上
	 * 
	 * @param sourcestr
	 *            数据库取得的信息
	 * @return
	 */
	public static String getStringToHTML(String sourcestr) {
		if (sourcestr == null) {
			return "";
		}
		sourcestr = sourcestr.replaceAll("&amp;", "\\x26");// &
		sourcestr = sourcestr.replaceAll("&lt;", "\\x3c");// <
		sourcestr = sourcestr.replaceAll("&gt;", "\\x3e");// >
		sourcestr = sourcestr.replaceAll("&nbsp;&nbsp;&nbsp;&nbsp;", "\\x09");// tab键
		sourcestr = sourcestr.replaceAll("&nbsp;", "\\x20");// 空格
		sourcestr = sourcestr.replaceAll("&quot;", "\\x22");// "

		sourcestr = sourcestr.replaceAll("<br>", "\r\n");// 回车换行
		sourcestr = sourcestr.replaceAll("<br>", "\r");// 回车
		sourcestr = sourcestr.replaceAll("<br>", "\n");// 换行
		return sourcestr;
	}

	/**
	 * 获得实际的客户端IP地址
	 * @param request
	 * @return
	 */
    public static String getRealIp(HttpServletRequest request) {
        String ip = request.getHeader("x-forwarded-for");
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("Proxy-Client-IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("WL-Proxy-Client-IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getRemoteAddr();
        }
        return ip;
    }

}

==> jwinner-kit-0.1.1-sources.jar: itez/kit/EWeb.java <==
package itez.kit;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.net.URLEncoder;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Map;
import java.util.regex.Pattern;

import javax.servlet.ServletInputStream;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * WEB工具类
 * @author netwild
 */
public abstract class EWeb {

	private static Logger log = LoggerFactory.getLogger(EWeb.class);

	/**
	 * 获取客户端IP地址
	 * @param request
	 * @return
	 */
	public static String getIpAddr(HttpServletRequest request) {
		String ip = request.getHeader("x-forwarded-for");
		if (EStr.isEmpty(ip) || "unknown".equalsIgnoreCase(ip)) ip = request.getHeader("Proxy-Client-IP");
		if (EStr.isEmpty(ip) || "unknown".equalsIgnoreCase(ip)) ip = request.getHeader("WL-Proxy-Client-IP");
		if (EStr.isEmpty(ip) || "unknown".equalsIgnoreCase(ip)) ip = request.getHeader("HTTP_CLIENT_IP");
		if (EStr.isEmpty(ip) || "unknown".equalsIgnoreCase(ip)) ip = request.getHeader("HTTP_X_FORWARDED_FOR");
		if (EStr.isEmpty(ip) || "unknown".equalsIgnoreCase(ip)) ip = request.getHeader("HTTP_X_FORWARDED");
		if (EStr.isEmpty(ip) || "unknown".equalsIgnoreCase(ip)) ip = request.getHeader("HTTP_FORWARDED_FOR");
		if (EStr.isEmpty(ip) || "unknown".equalsIgnoreCase(ip)) ip = request.getHeader("HTTP_FORWARDED");
		if (EStr.isEmpty(ip) || "unknown".equalsIgnoreCase(ip)) ip = request.getRemoteAddr();
		return ip;
	}

	/**
	 * 获取应用根路径（格式：http://www.domain.com:8888/app）
	 * 
	 * @param request
	 * @return
	 */
	public static String getContextPath(HttpServletRequest request) {
		String scheme, serverName, serverPort, context;
		
		scheme = request.getHeader("X-Forwarded-Scheme");
		if(EStr.isEmpty(scheme)) scheme = request.getScheme();
		
		serverName = request.getServerName();
		int port = request.getServerPort();
		serverPort = (port == 80 || port == 443) ? "" : ":" + port;
		context = request.getContextPath();
		
		return String.format("%s://%s%s%s", scheme, serverName, serverPort, context);
	}

	/**
	 * 获取完整请求路径(含内容路径及请求参数)
	 * 
	 * @param request
	 * @return
	 */
	public static String getFullUrl(HttpServletRequest request) {
		String resUrl = request.getRequestURL().toString();
		String params = request.getQueryString();
		if(EStr.notEmpty(params)) resUrl += "?" + params;
		return resUrl;
	}
	
	/**
	 * 获取请求来源路径
	 * 
	 * @param request
	 * @return
	 */
	public static String getReferer(HttpServletRequest request){
		return request.getHeader("referer");
	}
	
	/**
	 * 地址栏参数编码
	 * 
	 * @param url
	 * @return
	 */
	public static String UrlEncoder(String url){
		String urlEncode = url;
		try {
			urlEncode = URLEncoder.encode(url, EStr.Encoding);
		} catch (Exception e) {
			if(EProp.DevMode) e.printStackTrace();
		}
		return urlEncode;
	}
	
	/**
	 * 地址栏参数解码
	 * 
	 * @param url
	 * @return
	 */
	public static String UrlDecoder(String url){
		String urlDecode = url;
		try {
			urlDecode = URLDecoder.decode(url, EStr.Encoding);
		} catch (Exception e) {
			if(EProp.DevMode) e.printStackTrace();
		}
		return urlDecode;
	}

	/**
	 * 获取请求参数
	 * 
	 * @param request
	 * @param name
	 * @return
	 */
	public static String getParam(HttpServletRequest request, String name) {
		String value = request.getParameter(name);
		if (null != value && !value.isEmpty()) {
			try {
				return URLDecoder.decode(value, EStr.Encoding).trim();
			} catch (UnsupportedEncodingException e) {
				log.error("decode异常：" + value);
				return value;
			}
		}
		return value;
	}

	/**
	 * 获取ParameterMap
	 * @param request
	 * @return
	 */
	public static Map<String, String> getParamMap(HttpServletRequest request){
		Map<String, String> map = new HashMap<String, String>();
		Enumeration<String> enume = request.getParameterNames();
		while (enume.hasMoreElements()) {
			String name = (String) enume.nextElement();
			map.put(name, getParam(request, name));
		}
		return map;
	}
	
	/**
	 * 判断是否为Ajax请求
	 * @param request
	 * @return
	 */
	public static boolean isAjax(HttpServletRequest request){
        String header = request.getHeader("X-Requested-With");
        return "XMLHttpRequest".equalsIgnoreCase(header);
	}

	/**
	 * 输出servlet文本内容
	 * 
	 * @param response
	 * @param content
	 * @param contentType
	 */
	public static void outPage(HttpServletResponse response, String content) {
		outPage(response, content, EStr.Encoding);
	}

	/**
	 * 输出servlet文本内容
	 * 
	 * @param response
	 * @param content
	 * @param contentType
	 */
	public static void outPage(HttpServletResponse response, String content, String contentType) {
		if(EStr.isEmpty(contentType)) contentType = EStr.Encoding;
		response.setContentType(String.format("text/html; charset=%s", contentType));
		response.setCharacterEncoding(EStr.Encoding);
		try {
			byte[] contentBytes = content.getBytes(contentType);
			outPage(response, contentBytes, contentType);
			
			/*
			//改用ServletOutputStream输出，性能更好
			PrintWriter out = response.getWriter();
			out.print(content);
			out.flush();
			out.close();
			*/
			
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * 输出servlet文本内容
	 * 
	 * @param response
	 * @param content
	 * @param contentType
	 */
	public static void outPage(HttpServletResponse response, byte[] content, String contentType) {
		if(EStr.isEmpty(contentType)) contentType = EStr.Encoding;
		response.setContentType(String.format("text/html; charset=%s", contentType));
		response.setCharacterEncoding(EStr.Encoding);
		try {
			ServletOutputStream out = response.getOutputStream();
			out.write(content);
			out.flush();
			out.close();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * 请求流转字符串
	 * 
	 * @param request
	 * @return
	 */
	public static String requestStream(HttpServletRequest request) {
		InputStream inputStream = null;
		InputStreamReader inputStreamReader = null;
		BufferedReader bufferedReader = null;
		try {
			request.setCharacterEncoding(EStr.Encoding);
			inputStream = (ServletInputStream) request.getInputStream();
			inputStreamReader = new InputStreamReader(inputStream, EStr.Encoding);
			bufferedReader = new BufferedReader(inputStreamReader);
			String line = null;
			StringBuilder sb = new StringBuilder();
			while ((line = bufferedReader.readLine()) != null) {
				sb.append(line);
			}
			return sb.toString();
		} catch (IOException e) {
			log.error("request.getInputStream() to String 异常", e);
			return null;
		} finally { // 释放资源
			if(null != bufferedReader){
				try {
					bufferedReader.close();
				} catch (IOException e) {
					log.error("bufferedReader.close()异常", e);
				}
				bufferedReader = null;
			}
			
			if(null != inputStreamReader){
				try {
					inputStreamReader.close();
				} catch (IOException e) {
					log.error("inputStreamReader.close()异常", e);
				}
				inputStreamReader = null;
			}
			
			if(null != inputStream){
				try {
					inputStream.close();
				} catch (IOException e) {
					log.error("inputStream.close()异常", e);
				}
				inputStream = null;
			}
		}
	}
	
	/**
	 * 
	 * @param response
	 * @param domain		设置cookie所在域
	 * @param path			设置cookie所在路径
	 * @param isHttpOnly	是否只读
	 * @param name			cookie的名称
	 * @param value			cookie的值
	 * @param maxAge		cookie存放的时间(以秒为单位,假如存放三天,即3*24*60*60; 如果值为0,cookie将随浏览器关闭而清除)
	 */
	public static void addCookie(HttpServletRequest request, HttpServletResponse response, 
			String domain, String path, boolean isHttpOnly, 
			String name, String value, int maxAge) {
		Cookie cookie = new Cookie(name, value);

		// 所在域：比如a1.4bu4.com 和 a2.4bu4.com 共享cookie
		if(null != domain && !domain.isEmpty()){
			cookie.setDomain(domain);
		}
		
		// 设置cookie所在路径
		cookie.setPath("/");
		if(null != path && !path.isEmpty()){
			cookie.setPath(path);				
		}
		
		// 是否只读
		try {
			cookie.setHttpOnly(isHttpOnly);
		} catch (Exception e) {
			log.error("servlet容器版本太低，servlet3.0以前不支持设置cookie只读" + e.getMessage());
		}
		
		// 设置cookie的过期时间
		if (maxAge > 0){
			cookie.setMaxAge(maxAge);
		}
		
		// 添加cookie
		response.addCookie(cookie);
		/*
		System.out.println("cookie.getDomain：" + cookie.getDomain());
		System.out.println("cookie.getPath：" + cookie.getPath());
		System.out.println("cookie.getMaxAge：" + cookie.getMaxAge());
		System.out.println("cookie.getName：" + cookie.getName());
		System.out.println("cookie.getValue：" + cookie.getValue());
		Cookie[] cookies = request.getCookies();
		System.out.println("cookies：" + cookies.length);
		*/
	}

	/**
	 * 获取cookie的值
	 * 
	 * @param request
	 * @param name cookie的名称
	 * @return
	 */
	public static String getCookieValueByName(HttpServletRequest request, String name) {
		Cookie cookie = getCookieByName(request, name);
		if(cookie != null) return cookie.getValue();
		return null;
	}
	
	/**
	 * 清除cookie
	 * @param request
	 * @param response
	 * @param name cookie的名称
	 */
	public static void clearCookieByName(HttpServletRequest request, HttpServletResponse response, String name){
		Cookie cookie = getCookieByName(request, name);
		if(cookie != null){
			cookie.setValue(null);
			cookie.setPath("/");
			cookie.setMaxAge(0);
			response.addCookie(cookie);
		}
	}

	/**
	 * 获得cookie
	 * 
	 * @param request
	 * @param name cookie的名称
	 * @return
	 */
	public static Cookie getCookieByName(HttpServletRequest request, String name) {
		Map<String, Cookie> cookieMap = EWeb.readCookieMap(request);
		// 判断cookie集合中是否有我们像要的cookie对象 如果有返回它的值
		if (cookieMap.containsKey(name)) {
			Cookie cookie = (Cookie) cookieMap.get(name);
			return cookie;
		} else {
			return null;
		}
	}

	/**
	 * 获得所有cookie
	 * 
	 * @param request
	 * @return
	 */
	public static Map<String, Cookie> readCookieMap(HttpServletRequest request) {
		Map<String, Cookie> cookieMap = new HashMap<String, Cookie>();
		// 从request范围中得到cookie数组 然后遍历放入map集合中
		Cookie[] cookies = request.getCookies();
		//System.out.println("cookies：" + cookies.length);
		if (null != cookies) {
			for (int i = 0; i < cookies.length; i++) {
				cookieMap.put(cookies[i].getName(), cookies[i]);
			}
		}
		return cookieMap;
	}

	/**
	 * 去除HTML代码
	 * 
	 * @param inputString
	 * @return
	 */
	public static String HtmltoText(String inputString) {
		String htmlStr = inputString; // 含HTML标签的字符串
		String textStr = "";
		java.util.regex.Pattern p_script;
		java.util.regex.Matcher m_script;
		java.util.regex.Pattern p_style;
		java.util.regex.Matcher m_style;
		java.util.regex.Pattern p_html;
		java.util.regex.Matcher m_html;
		java.util.regex.Pattern p_ba;
		java.util.regex.Matcher m_ba;

		try {
			String regEx_script = "<[\\s]*?script[^>]*?>[\\s\\S]*?<[\\s]*?\\/[\\s]*?script[\\s]*?>"; // 定义script的正则表达式{或<script[^>]*?>[\\s\\S]*?<\\/script>
																										// }
			String regEx_style = "<[\\s]*?style[^>]*?>[\\s\\S]*?<[\\s]*?\\/[\\s]*?style[\\s]*?>"; // 定义style的正则表达式{或<style[^>]*?>[\\s\\S]*?<\\/style>
																									// }
			String regEx_html = "<[^>]+>"; // 定义HTML标签的正则表达式
			String patternStr = "\\s+";

			p_script = Pattern.compile(regEx_script, Pattern.CASE_INSENSITIVE);
			m_script = p_script.matcher(htmlStr);
			htmlStr = m_script.replaceAll(""); // 过滤script标签

			p_style = Pattern.compile(regEx_style, Pattern.CASE_INSENSITIVE);
			m_style = p_style.matcher(htmlStr);
			htmlStr = m_style.replaceAll(""); // 过滤style标签

			p_html = Pattern.compile(regEx_html, Pattern.CASE_INSENSITIVE);
			m_html = p_html.matcher(htmlStr);
			htmlStr = m_html.replaceAll(""); // 过滤html标签

			p_ba = Pattern.compile(patternStr, Pattern.CASE_INSENSITIVE);
			m_ba = p_ba.matcher(htmlStr);
			htmlStr = m_ba.replaceAll(""); // 过滤空格

			textStr = htmlStr;

		} catch (Exception e) {
			System.err.println("Html2Text: " + e.getMessage());
		}
		return textStr;// 返回文本字符串
	}

	/**
	 * 把页面的信息替换成我们想要的信息存放数据库里面
	 * 
	 * @param sourcestr
	 *            页面得到的信息
	 * @return
	 */
	public static String getHTMLToString(String sourcestr) {
		if (sourcestr == null) {
			return "";
		}
		sourcestr = sourcestr.replaceAll("\\x26", "&amp;");// &
		sourcestr = sourcestr.replaceAll("\\x3c", "&lt;");// <
		sourcestr = sourcestr.replaceAll("\\x3e", "&gt;");// >
		sourcestr = sourcestr.replaceAll("\\x09", "&nbsp;&nbsp;&nbsp;&nbsp;");// tab键
		sourcestr = sourcestr.replaceAll("\\x20", "&nbsp;");// 空格
		sourcestr = sourcestr.replaceAll("\\x22", "&quot;");// "

		sourcestr = sourcestr.replaceAll("\r\n", "<br>");// 回车换行
		sourcestr = sourcestr.replaceAll("\r", "<br>");// 回车
		sourcestr = sourcestr.replaceAll("\n", "<br>");// 换行
		return sourcestr;
	}

	/**
	 * 把数据库里面的信息回显到页面上
	 * 
	 * @param sourcestr
	 *            数据库取得的信息
	 * @return
	 */
	public static String getStringToHTML(String sourcestr) {
		if (sourcestr == null) {
			return "";
		}
		sourcestr = sourcestr.replaceAll("&amp;", "\\x26");// &
		sourcestr = sourcestr.replaceAll("&lt;", "\\x3c");// <
		sourcestr = sourcestr.replaceAll("&gt;", "\\x3e");// >
		sourcestr = sourcestr.replaceAll("&nbsp;&nbsp;&nbsp;&nbsp;", "\\x09");// tab键
		sourcestr = sourcestr.replaceAll("&nbsp;", "\\x20");// 空格
		sourcestr = sourcestr.replaceAll("&quot;", "\\x22");// "

		sourcestr = sourcestr.replaceAll("<br>", "\r\n");// 回车换行
		sourcestr = sourcestr.replaceAll("<br>", "\r");// 回车
		sourcestr = sourcestr.replaceAll("<br>", "\n");// 换行
		return sourcestr;
	}

	/**
	 * 获得实际的客户端IP地址
	 * @param request
	 * @return
	 */
    public static String getRealIp(HttpServletRequest request) {
        String ip = request.getHeader("x-forwarded-for");
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("Proxy-Client-IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("WL-Proxy-Client-IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getRemoteAddr();
        }
        return ip;
    }

}
